==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebSizeDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSizeDescription } from "./WebSizeDescription";
/**
 * @hidden
 */
export let WebSizeDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebSizeDescriptionMetadata extends Base {
        static b(a) {
            if (WebSizeDescriptionMetadata.a == null) {
                WebSizeDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebSizeDescriptionMetadata.c(WebSizeDescriptionMetadata.a);
            }
            if (a.j(WebSizeDescriptionMetadata.a)) {
                return;
            }
            a.y(WebSizeDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:Size");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
            a.item("Width", "Number:double");
            a.item("Height", "Number:double");
        }
        static d(a) {
            WebSizeDescriptionMetadata.b(a);
            a.aa("WebSize", () => new WebSizeDescription());
            a.z("WebSize", WebSizeDescriptionMetadata.a);
        }
    }
    WebSizeDescriptionMetadata.$t = /*@__PURE__*/ markType(WebSizeDescriptionMetadata, 'WebSizeDescriptionMetadata');
    WebSizeDescriptionMetadata.a = null;
    return WebSizeDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebSizeDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSizeDescription } from "./WebSizeDescription";
/**
 * @hidden
 */
export let WebSizeDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebSizeDescriptionMetadata extends Base {
        static b(a) {
            if (WebSizeDescriptionMetadata.a == null) {
                WebSizeDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebSizeDescriptionMetadata.c(WebSizeDescriptionMetadata.a);
            }
            if (a.k(WebSizeDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebSizeDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:Size");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Width", "Number:double");
            a.item("Height", "Number:double");
        }
        static d(a) {
            WebSizeDescriptionMetadata.b(a);
            a.ac("WebSize", () => new WebSizeDescription());
            a.ab("WebSize", WebSizeDescriptionMetadata.a);
        }
    }
    WebSizeDescriptionMetadata.$t = /*@__PURE__*/ markType(WebSizeDescriptionMetadata, 'WebSizeDescriptionMetadata');
    WebSizeDescriptionMetadata.a = null;
    return WebSizeDescriptionMetadata;
})();
